@@ -56,7 +56,7 @@ class NodeWayRelationQuery(CompoundQuery):
 query_index_lut = dict()
 query_index_lut[( (Node._level,) )] = NodeQuery
 query_index_lut[( (Way._level,) )] = WayQuery
-query_index_lut[( (Relation._level) )] = RelationQuery,
+query_index_lut[( (Relation._level,) )] = RelationQuery,
 query_index_lut[( (Node._level, Way._level) )] = NodeWayQuery,
 query_index_lut[( (Node._level, Relation._level) )] = NodeRelationQuery,
 query_index_lut[( (Way._level, Relation._level) )] = WayRelationQuery,
@@ -72,7 +72,11 @@ def element_query_factory(levels):
     levels = list(levels)
     levels = sorted(levels)
     levels = tuple(levels)
-    return query_index_lut[levels]
+    qc = query_index_lut[levels]
+    if isinstance(qc, tuple):
+        qc = qc[0]
+    return qc
+
 
 
 class QueryRegister:
@@ -111,7 +115,7 @@ class QueryRegister:
     def __repr__(self):
         s =  f'''{"".join(repr(qs) for qs in self.qc)}'''
         if self.qb.auto_recourse_down and self.output != Node:
-            if self.qb.output_mode.VERBOSITY is opf.Verbosity.CONCISE:
+            if self.qb.output_mode.VERBOSITY is (opf.Verbosity.CONCISE or opf.Verbosity.GENERIC):
                 if self.qb.output_mode.GEOMETRY is None:
                     s += "(._;>;);"
         return s
